==> navigine_sdk-1.1.0.tar.gz: ios/Classes/NavigineHelper.swift <==
//
//  NavigineHelper.swift
//  navigine_sdk
//
//  Created by Aawaz on 25/09/2021.
//
import Navigine
import Foundation
import Flutter


class NavigineHelper: NSObject, NavigineCoreDelegate, NavigineCoreLocationDelegate, NavigineCoreBluetoothDelegate {
    
    func navigineCore(_ navigineCore: NavigineCore, didUpdateBluetoothState status: CBManagerState) {
        
    }
    

    var navigineCore: NavigineCore?
    var methodChannel: FlutterMethodChannel?
    
    func setMethodChannel(methodChannel channel: FlutterMethodChannel?) {
        self.methodChannel = channel
    }

    func initilizeSDK(_ userHash: String, serverURL: String?) {
        if(serverURL == nil){
            navigineCore = NavigineCore(userHash: userHash)
        } else {
            navigineCore = NavigineCore(userHash: userHash, server: serverURL!)
        }
        navigineCore?.delegate = self
        navigineCore?.locationDelegate =  self
        navigineCore?.bluetoothDelegate = self
    }
    
    func setDelegate(deviceInfoDelegate: NavigineCoreNavigationDelegate) {
        navigineCore?.navigationDelegate = deviceInfoDelegate
    }

    func loadLocation(_ locationId: NSNumber?) {
        let locationIdInteger = locationId?.intValue ?? 0
        navigineCore?.downloadLocation(byId: locationIdInteger, forceReload: false, processBlock: { loadProcess in
            let val = NSNumber(value: loadProcess)
            self.methodChannel?.invokeMethod("location#onUpdate", arguments: val)
        }, successBlock: { userInfo in
            self.methodChannel?.invokeMethod("location#onFinished", arguments: nil)
        }) { error in
            let val = NSNumber(value: (error as NSError?)?.code ?? 0)
            self.methodChannel?.invokeMethod("location#onFailed", arguments: val)
        }
    }

    func startNavigation() {
        navigineCore?.startNavigine()
    }

    func stopNavigation() {
        navigineCore?.stopNavigine()
    }

    func getLocation() -> Any? {
        return Convert.locationInfo(toObject: navigineCore?.location)
    }

    func getDeviceInfo() -> Any? {
        return Convert.deviceInfo(toObject: navigineCore?.deviceInfo)
    }

}

==> navigine_sdk-1.1.2.tar.gz: ios/Classes/NavigineHelper.swift <==
//
//  NavigineHelper.swift
//  navigine_sdk
//
//  Created by Aawaz on 25/09/2021.
//
import Navigine
import Foundation
import Flutter


class NavigineHelper: NSObject, NavigineCoreDelegate, NavigineCoreLocationDelegate, NavigineCoreBluetoothDelegate {
    
    func navigineCore(_ navigineCore: NavigineCore, didUpdateBluetoothState status: CBManagerState) {
        
    }
    

    var navigineCore: NavigineCore?
    var methodChannel: FlutterMethodChannel?
    
    func setMethodChannel(methodChannel channel: FlutterMethodChannel?) {
        self.methodChannel = channel
    }

    func initilizeSDK(_ userHash: String, serverURL: String?) {
        if(serverURL == nil){
            navigineCore = NavigineCore(userHash: userHash)
        } else {
            navigineCore = NavigineCore(userHash: userHash, server: serverURL!)
        }
        navigineCore?.delegate = self
        navigineCore?.locationDelegate =  self
        navigineCore?.bluetoothDelegate = self
    }
    
    func setDelegate(deviceInfoDelegate: NavigineCoreNavigationDelegate) {
        navigineCore?.navigationDelegate = deviceInfoDelegate
    }

    func loadLocation(_ locationId: NSNumber?) {
        let locationIdInteger = locationId?.intValue ?? 0
        
        
        navigineCore?.downloadLocation(byId: locationIdInteger, forceReload: true, processBlock: {(_ loadProcess: Int) in let val = NSNumber(value: loadProcess)
            self.methodChannel?.invokeMethod("location#onUpdate", arguments: val)
        }, successBlock: {(_ userInfo:[AnyHashable : Any]?) in
            self.methodChannel?.invokeMethod("location#onFinished", arguments: nil)
        }, fail: { (_ error: Error?) in
            print(error)
        })
    }

    func startNavigation() {
        navigineCore?.startNavigine()
    }

    func stopNavigation() {
        navigineCore?.stopNavigine()
    }

    func getLocation() -> Any? {
        return Convert.locationInfo(toObject: navigineCore?.location)
    }

    func getDeviceInfo() -> Any? {
        return Convert.deviceInfo(toObject: navigineCore?.deviceInfo)
    }

}
